/**
  *  \file client/widgets/markerlist.cc
  *  \brief WMarkerList widget
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <algorithm>
#include "client/widgets/markerlist.h"
#include "client/markerconfig.h"
#include "client/marks.h"
#include "cpluslib/format.h"
#include "game/drawing.h"
#include "gfx/gfxcontext.h"
#include "gfx/palette.h"
#include "util/nls.h"

/** Constructor.
    \param id Widget Id */
WMarkerList::WMarkerList(int id)
    : UIListbox(id,
                ConfigMarkerOption::NUM_CANNED_MARKERS,
                20*font_ems[FONT_NORMAL],
                ConfigMarkerOption::NUM_CANNED_MARKERS)
{
    setItemHeight(std::max(20, font_heights[FONT_NORMAL]));
}

WMarkerList::~WMarkerList()
{ }

void
WMarkerList::drawPart(GfxCanvas& can, int from, int to)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.setTextAlign(0, 1);
    ctx.useFont(*fonts[FONT_NORMAL]);
    for (int i = from; i < to; ++i) {
        // Prepare
        GfxRect area;
        prepareEntry(ctx, ColorStyle, i, &area);

        // Draw
        int n = getTop() + i;
        if (n >= 0 && n < ConfigMarkerOption::NUM_CANNED_MARKERS) {
            const ConfigMarkerOption& m = ConfigMarkerOption::getCannedMarker(n);

            // Compute geometry and show text
            GfxRect box = area.splitX(20);
            area.consumeX(5);

            string_t note = m.getNote();
            if (note.empty()) {
                if (n == 0) {
                    note = _("Default marker");
                } else {
                    note = format(_("Marker %d"), i);
                }
            }
            outTextF(ctx, area, note);

            // Show marker
            box.grow(-1, -1);
            if (n != getCurrent()) {
                drawSolidBar(ctx, box, UIColor::tc_Static);
            } else {
                ctx.setColor(UIColor::tc_Faded);
                drawRectangle(ctx, box);
            }
            ctx.setRawColor(standard_colors[GDrawing::getColorFromUserColor(m.getColorIndex())]);
            drawMarker(ctx, getUserMarker(m.getType(), true), box.getCenter());
        }
    }
}
