#
#  Script for building PCC2 Linux (32-bit) package
#
#  Start with an empty directory.
#    cvs co pdk pcc-v2 cpluslib
#    bash pcc-v2/scripts/build_dist_linux.sh
#  Find complete package in current directory.
#
#  This uses uchroot to build the package using a conserved 32-bit toolchain.
#

set -e

UCHROOT=$HOME/src/uchroot/uchroot
TOOLCHAIN=$HOME/gcc-3.3-root
CC=gcc-3.3
JOBS=7

run() {
    # Run a command within the toolchain container.
    # - make toolchain container read-only
    # - give it a writable /tmp
    # - make current directory available as /home, writable
    # - turn off NLS nuisances
    "$UCHROOT" -R/="$TOOLCHAIN" -W/dev=/dev -W/tmp=/tmp -W/home=. -DLC_ALL=C "$@"
}

# Start by making the PDK
run -C/home/pdk make CC="$CC"

# Configure PCC-v2
run -C/home/pcc-v2 ./configure CC="$CC" --disable-inplace --with-pdk=../pdk

# Make PCC-v2
run -C/home/pcc-v2 make -j$JOBS

# Build the package. This requires simulated root privileges.
run -C/home/pcc-v2 -root make deb

# Move package here.
mv -i pcc-v2/pcc2*.deb .
